@@ -1,6 +1,6 @@
 <?php
 
-static $data = array (
+return array (
   'À' => 'À',
   'Á' => 'Á',
   'Â' => 'Â',
@@ -941,9 +941,5 @@ static $data = array (
   '𑒾' => '𑒾',
   '𑖺' => '𑖺',
   '𑖻' => '𑖻',
+  '𑤸' => '𑤸',
 );
-
-$result =& $data;
-unset($data);
-
-return $result;
