@@ -18,9 +18,11 @@ if (\PHP_VERSION_ID >= 70400) {
 if (!function_exists('get_mangled_object_vars')) {
     function get_mangled_object_vars($object) { return p\Php74::get_mangled_object_vars($object); }
 }
-if (!function_exists('mb_str_split') && function_exists('mb_substr')) {
-    function mb_str_split($string, $length = 1, $encoding = null) { return p\Php74::mb_str_split($string, $length, $encoding); }
-}
 if (!function_exists('password_algos')) {
     function password_algos() { return p\Php74::password_algos(); }
 }
+if (extension_loaded('mbstring')) {
+    if (!function_exists('mb_str_split')) {
+        function mb_str_split($string, $length = 1, $encoding = null) { return p\Php74::mb_str_split($string, $length, $encoding); }
+    }
+}
