@@ -25,10 +25,6 @@ class TestListenerTrait
 
     public function startTestSuite($mainSuite)
     {
-        if (null !== self::$enabledPolyfills) {
-            return;
-        }
-        self::$enabledPolyfills = false;
         $warnings = [];
 
         foreach ($mainSuite->tests() as $suite) {
@@ -53,7 +49,14 @@ class TestListenerTrait
             }
             $testedClass = new \ReflectionClass($m[1].$m[2]);
             $bootstrap = \dirname($testedClass->getFileName()).'/bootstrap';
-            $bootstrap = new \SplFileObject($bootstrap.(\PHP_VERSION_ID >= 80000 && file_exists($bootstrap.'80.php') ? '80' : '').'.php');
+            if (\PHP_VERSION_ID >= 80200 && file_exists($bootstrap.'82.php')) {
+                $bootstrap .= '82';
+            } elseif (\PHP_VERSION_ID >= 80100 && file_exists($bootstrap.'81.php')) {
+                $bootstrap .= '81';
+            } elseif (\PHP_VERSION_ID >= 80000 && file_exists($bootstrap.'80.php')) {
+                $bootstrap .= '80';
+            }
+            $bootstrap = new \SplFileObject($bootstrap.'.php');
             $newWarnings = 0;
             $defLine = null;
 
@@ -109,7 +112,7 @@ use {$testedClass->getNamespaceName()} as p;
 
 function {$f['name']}{$f['signature']}
 {
-    if ('{$testClass}' === TestListenerTrait::\$enabledPolyfills) {
+    if ('{$testClass} with polyfills enabled' === TestListenerTrait::\$enabledPolyfills) {
         {$f['return']}{$f['args']};
     }
 
@@ -123,16 +126,25 @@ EOPHP
                     $polyfillSignature = ReflectionCaster::castFunctionAbstract(new \ReflectionFunction($testNamespace.'\\'.$f['name']), [], new Stub(), true);
                     $polyfillSignature = ReflectionCaster::getSignature($polyfillSignature);
 
+                    if ('mb_get_info' === $r->name && false === strpos($originalSignature, '|null') && false !== strpos($polyfillSignature, '|null')) {
+                        // Added to PHP 8.2.14/8.3.1
+                        $originalSignature .= '|null';
+                    }
+
+                    if (false === strpos($bootstrap->getPath(), '80.php')) {
+                        // mixed return type cannot be used before PHP 8
+                        $originalSignature = str_replace(': mixed', '', $originalSignature);
+                    }
+
                     $map = [
                         '?' => '',
-                        'IDNA_DEFAULT' => \PHP_VERSION_ID >= 80100 ? 'IDNA_DEFAULT' : '0',
                         'array|string|null $string' => 'array|string $string',
                         'array|string|null $from_encoding = null' => 'array|string|null $from_encoding = null',
                         'array|string|null $from_encoding' => 'array|string $from_encoding',
                     ];
 
-                    if (strtr($polyfillSignature, $map) !== $originalSignature) {
-                        $warnings[] = TestListener::warning("Incompatible signature for PHP >= 8:\n- {$f['name']}$originalSignature\n+ {$f['name']}$polyfillSignature");
+                    if (strtr($polyfillSignature, $map) !== str_replace('?', '', $originalSignature)) {
+                        $warnings[] = TestListener::warning("Incompatible signature for PHP >= 8 in {$bootstrap->getPathname()}:\n- {$f['name']}$originalSignature\n+ {$f['name']}$polyfillSignature");
                     }
                 }
             }
